# -*- coding: utf-8 -*-
"""
Mapping Learning Graphical User Interface

History:

* Initially generated '.\maplearn\app\gui\maplearn_main.ui'
  (PyQt5 UI code generator 5.6)
"""
from PyQt5 import Qt, QtCore, QtGui, QtWidgets
try:
    from PyQt5 import QtWebEngineWidgets
except ImportError:
    from PyQt5 import QtWebKitWidgets as QtWebEngineWidgets

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(1200, 700)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/logo/Icon/logo.png"),
                       QtGui.QIcon.Normal, QtGui.QIcon.Off)
        MainWindow.setWindowIcon(icon)

        # icons
        _icons = {}
        for i in ['new', 'open', 'save', 'saveas', 'quit', 'io', 'preprocess',
                  'process']:
            _icons[i] = QtGui.QIcon()
            _icons[i].addPixmap(QtGui.QPixmap(":/icon/Icon/%s-icon-wh.png" % i),
                                QtGui.QIcon.Active, QtGui.QIcon.On)
            if i in ['io', 'preprocess', 'process']:
                _icons[i].addPixmap(QtGui.QPixmap(":/icon/Icon/%s-icon-wh.png" % i),
                    QtGui.QIcon.Normal, QtGui.QIcon.Off)
        
        __styleSheet = """
                       QToolBox, QWidget, QFrame { color: white ; background-color: #383838 }
                       QToolBox::tab:!selected { font: 13pt }
                       QToolBox::tab:selected { font: 15pt bold }
                       QLineEdit, QSpinBox, QPushButton, QListWidget { color: #383838 ; background-color: white }
                       QPushButton:disabled, QSpinBox:disabled, QLineEdit:disabled { background-color:#585858 ; color: #484848}
                       QCheckBox::indicator:unchecked { color: #383838 ; background-color: white }
                       QLabel { color: white ; font: 10pt }
                       QComboBox { background-color:white ; color:#383838 }
                       QComboBox::item { color:#383838 ; background-color: white ; 
                           selection-color: white ; selection-background-color: #787878}
                       QGroupBox { font: bold }
                       QWidget#frm_io { margin:20px }
                       QComboBox#cbo_process, QPushButton#btn_run { font: 17pt bold}
                       """
        
        # Try: create a gradient from tab to tab...
#        QWidget#frm_io, QWidget#frm_io > *, QToolBox::tab:first, QToolBox::tab:first > * { background-color: #888888 }
#        QLabel#__lab_io_label, QLabel#__lab_io_label_id, QLabel#__lab_io_features { background-color: #888888 }
#        QWidget#frm_preprocess, QWidget#frm_preprocess > *, QToolBox::tab:second, QToolBox::tab:second > * { background-color: #686868 }
#        QGroupBox#gb_pre_reduction > * { background-color: #686868 }
#        QWidget#frm_process, QWidget#frm_process > *, QToolBox::tab:last, QToolBox::tab:last > * { background-color: #484848 }
        __size = {'l_min': QtCore.QSize(300, 400),
                  'l_max':QtCore.QSize(4000, 16777215),
                  'r_min': QtCore.QSize(800, 400),
                  'r_max':QtCore.QSize(4000, 16777215),
                  }
        
        __vSpacer = QtWidgets.QSpacerItem(20, 100,
                                           QtWidgets.QSizePolicy.Minimum,
                                           QtWidgets.QSizePolicy.Expanding)
        
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.__vl_centralWidget = QtWidgets.QVBoxLayout(self.centralwidget)
        self.__vl_centralWidget.setObjectName("__vl_centralWidget")
        
        self.frm_main = QtWidgets.QFrame(self.centralwidget)
        self.frm_main.setMinimumSize(__size['l_min'])
        self.frm_main.setMaximumSize(__size['l_max'])
        self.frm_main.setToolTip("")
        self.frm_main.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.frm_main.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frm_main.setObjectName("frm_main")
        self.frm_main.setStyleSheet(__styleSheet)
        self.__vl_main = QtWidgets.QVBoxLayout(self.frm_main)
        self.__vl_main.setObjectName("__vl_main")

        # Combox box with kinds of process (classification, clustering...)
        self.__hl_cbo_process = QtWidgets.QHBoxLayout()
        self.__hl_cbo_process.setContentsMargins(10, 10, 10, 20)

        self.cbo_process = QtWidgets.QComboBox(self.frm_main)
        self.cbo_process.setObjectName("cbo_process")
        #self.cbo_process.setEditable(True)
        #self.cbo_process.lineEdit().setReadOnly(True)
        #self.cbo_process.lineEdit().setAlignment(QtCore.Qt.AlignCenter);
        for _ in range(3):
            self.cbo_process.addItem("")
        self.__hl_cbo_process.addWidget(self.cbo_process)
        self.__vl_main.addLayout(self.__hl_cbo_process)
        
        self.tbx_main = QtWidgets.QToolBox(self.frm_main)
        self.tbx_main.setSizeIncrement(QtCore.QSize(0, 0))
        self.tbx_main.setBaseSize(QtCore.QSize(0, 0))
        self.tbx_main.setContextMenuPolicy(QtCore.Qt.DefaultContextMenu)
        self.tbx_main.setAcceptDrops(False)
        self.tbx_main.setStatusTip("")
        self.tbx_main.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.tbx_main.setFrameShadow(QtWidgets.QFrame.Plain)
        self.tbx_main.setLineWidth(1)
        self.tbx_main.setObjectName("tbx_main")

        #INPUT/OUTPUT
        self.frm_io = QtWidgets.QWidget()
        self.frm_io.setStatusTip("")
        self.frm_io.setAccessibleName("")
        self.frm_io.setObjectName("frm_io")
        self.tbx_main.addItem(self.frm_io, _icons['io'], "")
        self.__vl_io = QtWidgets.QVBoxLayout(self.frm_io)
        self.__vl_io.setContentsMargins(10, 20, 10, 10)
        self.__vl_io.setObjectName("__vl_io")
        self.__hl_io_1 = QtWidgets.QHBoxLayout()
        self.__hl_io_1.setObjectName("__hl_io_1")
        self.__lbl_samples = QtWidgets.QLabel(self.frm_io)
        self.__lbl_samples.setObjectName("lbl_samples")
        self.__hl_io_1.addWidget(self.__lbl_samples)
        self.le_io_samples = QtWidgets.QLineEdit(self.frm_io)
        self.le_io_samples.setObjectName("le_io_samples")
        self.__hl_io_1.addWidget(self.le_io_samples)
        self.btn_io_samples = QtWidgets.QPushButton(self.frm_io)
        self.btn_io_samples.setMaximumSize(QtCore.QSize(40, 16777215))
        self.btn_io_samples.setObjectName("btn_io_samples")
        self.__hl_io_1.addWidget(self.btn_io_samples)
        self.__vl_io.addLayout(self.__hl_io_1)
        self.__hl_io_2 = QtWidgets.QHBoxLayout()
        self.__hl_io_2.setObjectName("__hl_io_2")
        self.__lbl_data = QtWidgets.QLabel(self.frm_io)
        self.__lbl_data.setObjectName("lbl_data")
        self.__hl_io_2.addWidget(self.__lbl_data)
        self.le_io_data = QtWidgets.QLineEdit(self.frm_io)
        self.le_io_data.setObjectName("le_io_data")
        self.__hl_io_2.addWidget(self.le_io_data)
        self.btn_io_data = QtWidgets.QPushButton(self.frm_io)
        self.btn_io_data.setMaximumSize(QtCore.QSize(40, 16777215))
        self.btn_io_data.setObjectName("btn_io_data")
        self.__hl_io_2.addWidget(self.btn_io_data)
        self.__vl_io.addLayout(self.__hl_io_2)
        self.__vl_io.addItem(__vSpacer)
        self.__gb_io_attributes = QtWidgets.QGroupBox(self.frm_io)
        self.__gb_io_attributes.setObjectName("__gb_io_attributes")
        self.__vl_io_features = QtWidgets.QVBoxLayout(self.__gb_io_attributes)
        self.__vl_io_features.setObjectName("__vl_io_features")
        self.__vl_io_features.setContentsMargins(10, 20, 10, 10)
        self.__spl_io_1 = QtWidgets.QSplitter(self.__gb_io_attributes)
        self.__spl_io_1.setOrientation(QtCore.Qt.Horizontal)
        self.__spl_io_1.setObjectName("__spl_io_1")
        self.__lbl_io_label_id = QtWidgets.QLabel(self.__spl_io_1)
        self.__lbl_io_label_id.setObjectName("__lab_io_label_id")
        self.le_io_label_id = QtWidgets.QLineEdit(self.__spl_io_1)
        self.le_io_label_id.setMaximumSize(QtCore.QSize(200, 16777215))
        self.le_io_label_id.setObjectName("le_io_label_id")
        self.__vl_io_features.addWidget(self.__spl_io_1)
        self.__spl_io_2 = QtWidgets.QSplitter(self.__gb_io_attributes)
        self.__spl_io_2.setOrientation(QtCore.Qt.Horizontal)
        self.__spl_io_2.setObjectName("__spl_io_2")
        self.__lbl_io_label = QtWidgets.QLabel(self.__spl_io_2)
        self.__lbl_io_label.setObjectName("__lab_io_label")
        self.le_io_label = QtWidgets.QLineEdit(self.__spl_io_2)
        self.le_io_label.setMaximumSize(QtCore.QSize(200, 16777215))
        self.le_io_label.setObjectName("le_io_label")
        self.__vl_io_features.addWidget(self.__spl_io_2)
        self.__spl_io_3 = QtWidgets.QSplitter(self.__gb_io_attributes)
        self.__spl_io_3.setOrientation(QtCore.Qt.Horizontal)
        self.__spl_io_3.setObjectName("__spl_io_3")
        self.__lbl_io_features = QtWidgets.QLabel(self.__spl_io_3)
        self.__lbl_io_features.setObjectName("__lab_io_features")
        self.le_io_features = QtWidgets.QLineEdit(self.__spl_io_3)
        self.le_io_features.setMaximumSize(QtCore.QSize(200, 16777215))
        self.le_io_features.setObjectName("le_io_features")
        self.__vl_io_features.addWidget(self.__spl_io_3)
        self.__vl_io.addWidget(self.__gb_io_attributes)
        self.__vl_io.addItem(__vSpacer)
        self.__hl_io_3 = QtWidgets.QHBoxLayout()
        self.__hl_io_3.setObjectName("__hl_io_3")
        self.__lbl_output = QtWidgets.QLabel(self.frm_io)
        self.__lbl_output.setObjectName("lbl_output")
        self.__hl_io_3.addWidget(self.__lbl_output)
        self.le_io_output = QtWidgets.QLineEdit(self.frm_io)
        self.le_io_output.setObjectName("le_io_output")
        self.__hl_io_3.addWidget(self.le_io_output)
        self.btn_io_output = QtWidgets.QPushButton(self.frm_io)
        self.btn_io_output.setMaximumSize(QtCore.QSize(40, 16777215))
        self.btn_io_output.setObjectName("btn_io_output")
        self.__hl_io_3.addWidget(self.btn_io_output)
        self.__vl_io.addLayout(self.__hl_io_3)

        # PREPROCESS
        self.frm_preprocess = QtWidgets.QWidget()
        self.frm_preprocess.setObjectName("frm_preprocess")
        self.tbx_main.addItem(self.frm_preprocess, _icons['preprocess'], "")
        self.__vl_preprocess = QtWidgets.QVBoxLayout(self.frm_preprocess)
        self.__vl_preprocess.setContentsMargins(10, 20, 10, 10)
        self.__vl_preprocess.setObjectName("__vl_preprocess")
        self.__vl_preprocess.addItem(__vSpacer)
        self.chk_pre_scale = QtWidgets.QCheckBox(self.frm_preprocess)
        self.chk_pre_scale.setChecked(True)
        self.chk_pre_scale.setObjectName("chk_pre_scale")
        self.__vl_preprocess.addWidget(self.chk_pre_scale)
        self.chk_pre_balance = QtWidgets.QCheckBox(self.frm_preprocess)
        self.chk_pre_balance.setObjectName("chk_pre_balance")
        self.__vl_preprocess.addWidget(self.chk_pre_balance)
        self.chk_pre_separability = QtWidgets.QCheckBox(self.frm_preprocess)
        self.chk_pre_separability.setObjectName("chk_pre_separability")
        self.__vl_preprocess.addWidget(self.chk_pre_separability)
        self.__vl_preprocess.addItem(__vSpacer)
        self.gb_pre_reducion = QtWidgets.QGroupBox(self.frm_preprocess)
#        self.gb_pre_reducion.setMinimumSize(QtCore.QSize(20, 120))
        self.gb_pre_reducion.setObjectName("gb_pre_reducion")
        self.__vl_pre_reduction = QtWidgets.QVBoxLayout(self.gb_pre_reducion)
        self.__vl_pre_reduction.setObjectName("__vl_pre_reduction")
        self.spl_pre_reduction = QtWidgets.QSplitter(self.gb_pre_reducion)
        self.spl_pre_reduction.setOrientation(QtCore.Qt.Horizontal)
        self.spl_pre_reduction.setObjectName("spl_pre_reduction")
        self.__lbl_pre_reduce = QtWidgets.QLabel(self.spl_pre_reduction)
        self.__lbl_pre_reduce.setObjectName("__lab_pre_reduce")
        self.cbo_pre_reduce = QtWidgets.QComboBox(self.spl_pre_reduction)
        self.cbo_pre_reduce.setObjectName("cbo_pre_reduce")
        self.cbo_pre_reduce.addItem("")
        self.cbo_pre_reduce.setItemText(0, "")
        self.__vl_pre_reduction.addWidget(self.spl_pre_reduction)
        self.spl_pre_ncomp = QtWidgets.QSplitter(self.gb_pre_reducion)
        self.spl_pre_ncomp.setOrientation(QtCore.Qt.Horizontal)
        self.spl_pre_ncomp.setObjectName("spl_pre_ncomp")
        self.__lbl_pre_ncomp = QtWidgets.QLabel(self.spl_pre_ncomp)
        self.__lbl_pre_ncomp.setEnabled(True)
        self.__lbl_pre_ncomp.setObjectName("__lab_pre_ncomp")
        self.sb_pre_ncomp = QtWidgets.QSpinBox(self.spl_pre_ncomp)
        self.sb_pre_ncomp.setEnabled(False)
        self.sb_pre_ncomp.setMaximumSize(QtCore.QSize(100, 16777215))
        self.sb_pre_ncomp.setMinimum(1)
        self.sb_pre_ncomp.setMaximum(160000)
        self.sb_pre_ncomp.setObjectName("sb_pre_ncomp")
        self.__vl_pre_reduction.addWidget(self.spl_pre_ncomp)
        self.__vl_preprocess.addWidget(self.gb_pre_reducion)
        self.__vl_preprocess.addItem(__vSpacer)

        # PROCESS
        self.frm_process = QtWidgets.QWidget()
        self.tbx_main.addItem(self.frm_process, _icons['process'], "")
        self.frm_process.setObjectName("frm_process")
        self.__vl_process = QtWidgets.QVBoxLayout(self.frm_process)
        self.__vl_process.setContentsMargins(10, 20, 10, 10)
        self.__vl_process.setObjectName("__vl_process")
        self.spl_pro_algorithm = QtWidgets.QSplitter(self.frm_process)
        self.spl_pro_algorithm.setOrientation(QtCore.Qt.Horizontal)
        self.spl_pro_algorithm.setObjectName("spl_pro_algorithm")
        self.__lbl_pro_algorithm = QtWidgets.QLabel(self.spl_pro_algorithm)
        self.__lbl_pro_algorithm.setObjectName("__lab_pro_algorithm")
        self.lst_pro_algorithm = QtWidgets.QListWidget(self.spl_pro_algorithm)
        self.lst_pro_algorithm.setMaximumSize(QtCore.QSize(200, 600))
        self.lst_pro_algorithm.setAutoScrollMargin(8)
        self.lst_pro_algorithm.setSelectionMode(QtWidgets.QAbstractItemView.MultiSelection)
        self.lst_pro_algorithm.setObjectName("lst_pro_algorithm")
        self.__vl_process.addWidget(self.spl_pro_algorithm)
        self.__vl_process.addItem(__vSpacer)
        self.__hl_pro_1 = QtWidgets.QHBoxLayout()
        self.__hl_pro_1.setObjectName("hl_pro_1")
        self.__lbl_pro_kfold = QtWidgets.QLabel(self.frm_process)
        self.__lbl_pro_kfold.setObjectName("__lbl_pro_kfold")
        self.__hl_pro_1.addWidget(self.__lbl_pro_kfold)
        self.sbo_pro_kfold = QtWidgets.QSpinBox(self.frm_process)
        self.sbo_pro_kfold.setMinimum(2)
        self.sbo_pro_kfold.setMaximum(10)
        self.sbo_pro_kfold.setProperty("value", 3)
        self.sbo_pro_kfold.setObjectName("sbo_pro_kfold")
        self.__hl_pro_1.addWidget(self.sbo_pro_kfold)
        self.__vl_process.addLayout(self.__hl_pro_1)
        self.__vl_pro_1 = QtWidgets.QVBoxLayout()
        self.__vl_pro_1.setObjectName("vl_pro_1")
        self.chk_pro_optimize = QtWidgets.QCheckBox(self.frm_process)
        self.chk_pro_optimize.setObjectName("chk_pro_optimize")
        self.__vl_pro_1.addWidget(self.chk_pro_optimize)
        self.chk_pro_predict = QtWidgets.QCheckBox(self.frm_process)
        self.chk_pro_predict.setObjectName("chk_pro_predict")
        self.__vl_pro_1.addWidget(self.chk_pro_predict)
        self.__vl_process.addLayout(self.__vl_pro_1)
        self.__vl_process.addItem(__vSpacer)
        self.__hl_pro_2 = QtWidgets.QHBoxLayout()
        self.__hl_pro_2.setObjectName("hl_pro_2")
        self.__lbl_pro_distance = QtWidgets.QLabel(self.frm_process)
        self.__lbl_pro_distance.setObjectName("__lbl_pro_distance")
        self.__hl_pro_2.addWidget(self.__lbl_pro_distance)
        self.cbo_pro_distance = QtWidgets.QComboBox(self.frm_process)
        self.cbo_pro_distance.setObjectName("cbo_pro_distance")
        self.cbo_pro_distance.addItem("")
        self.cbo_pro_distance.addItem("")
        self.__hl_pro_2.addWidget(self.cbo_pro_distance)
        self.__vl_process.addLayout(self.__hl_pro_2)
        self.__vl_process.addItem(__vSpacer)
        
        # RUN button
        self.__hl_pro_3 = QtWidgets.QHBoxLayout()
        self.__hl_pro_3.setObjectName("hl_pro_3")
        self.btn_run = QtWidgets.QPushButton(self.frm_process)
        self.btn_run.setObjectName("btn_run")
        self.__hl_pro_3.addWidget(self.btn_run)
        self.__vl_process.addLayout(self.__hl_pro_3)

        # Build left part of UI
        self.__vl_main.addWidget(self.tbx_main)
        self.__vl_centralWidget.addWidget(self.frm_main)
        MainWindow.setCentralWidget(self.centralwidget)

        # Menu bar
        self.menubar = QtWidgets.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 1200, 26))
        self.menubar.setObjectName("menubar")
        self.menuFichier = QtWidgets.QMenu(self.menubar)
        self.menuFichier.setObjectName("menuFichier")
        self.menuAide = QtWidgets.QMenu(self.menubar)
        self.menuAide.setObjectName("menuAide")
        MainWindow.setMenuBar(self.menubar)

        # Build right part of UI (documentation)
        self.dock_doc = QtWidgets.QDockWidget(MainWindow)
        self.dock_doc.setMinimumSize(__size['r_min'])
        self.dock_doc.setMaximumSize(__size['r_max'])
        self.dock_doc.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.dock_doc.setObjectName("dock_doc")
        self.__dock_web = QtWidgets.QWidget()
        self.__dock_web.setObjectName("__dock_web")
        self.__hl_doc = QtWidgets.QHBoxLayout(self.__dock_web)
        self.__hl_doc.setContentsMargins(0, 0, 0, 0)
        self.__hl_doc.setObjectName("__hl_doc")
        try:
            self.web_doc = QtWebEngineWidgets.QWebEngineView(self.__dock_web)
        except AttributeError:
            self.web_doc = QtWebEngineWidgets.QWebView(self.__dock_web)
        self.web_doc.setObjectName("web_doc")
        self.__hl_doc.addWidget(self.web_doc)
        self.dock_doc.setWidget(self.__dock_web)
        MainWindow.addDockWidget(QtCore.Qt.DockWidgetArea(2), self.dock_doc)

        self.statusbar = QtWidgets.QStatusBar(MainWindow)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)
        self.action_quit = QtWidgets.QAction(MainWindow)

        # menu items
        self.action_quit.setIcon(_icons['quit'])
        self.action_quit.setObjectName("action_quit")
        self.action_open = QtWidgets.QAction(MainWindow)
        self.action_open.setIcon(_icons['open'])
        self.action_open.setObjectName("action_open")
        self.action_new = QtWidgets.QAction(MainWindow)
        self.action_new.setIcon(_icons['new'])
        self.action_new.setObjectName("action_new")
        self.action_save = QtWidgets.QAction(MainWindow)
        self.action_save.setIcon(_icons['save'])
        self.action_save.setObjectName("action_save")
        self.action_saveas = QtWidgets.QAction(MainWindow)
        self.action_saveas.setIcon(_icons['saveas'])
        self.action_saveas.setObjectName("action_saveas")
        self.actionA_propos = QtWidgets.QAction(MainWindow)
        self.actionA_propos.setObjectName("actionA_propos")
        self.action_doc = QtWidgets.QAction(MainWindow)
        self.action_doc.setObjectName("action_doc")

        # menus
        self.menuFichier.addAction(self.action_new)
        self.menuFichier.addAction(self.action_open)
        self.menuFichier.addSeparator()
        self.menuFichier.addAction(self.action_save)
        self.menuFichier.addAction(self.action_saveas)
        self.menuFichier.addSeparator()
        self.menuFichier.addAction(self.action_quit)
        self.menuAide.addAction(self.action_doc)
        self.menuAide.addAction(self.actionA_propos)
        self.menubar.addAction(self.menuFichier.menuAction())
        self.menubar.addAction(self.menuAide.menuAction())

        # labels
        self.__lbl_samples.setBuddy(self.le_io_samples)
        self.__lbl_data.setBuddy(self.le_io_data)
        self.__lbl_io_label_id.setBuddy(self.le_io_label_id)
        self.__lbl_io_label.setBuddy(self.le_io_label)
        self.__lbl_io_features.setBuddy(self.le_io_features)
        self.__lbl_output.setBuddy(self.le_io_output)
        self.__lbl_pre_reduce.setBuddy(self.cbo_pre_reduce)
        self.__lbl_pre_ncomp.setBuddy(self.sb_pre_ncomp)
        self.__lbl_pro_algorithm.setBuddy(self.lst_pro_algorithm)
        self.__lbl_pro_kfold.setBuddy(self.sbo_pro_kfold)
        self.__lbl_pro_distance.setBuddy(self.cbo_pro_distance)

        self.retranslateUi(MainWindow)
        self.tbx_main.layout().setSpacing(7)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)
        
    def initUi(self, MainWindow):
        """
        Reset to defaults
        """
        self.tbx_main.setCurrentIndex(0) # Focus on IO form
        self.btn_run.setEnabled(False)
        self.le_io_features.setEnabled(False)
        self.le_io_label.setEnabled(False)
        self.le_io_label_id.setEnabled(False)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "Mapping Learning"))
        self.cbo_process.setStatusTip(_translate("MainWindow", "Choisissez le type de traitement à réaliser : classification, clustering ou régression"))
        self.cbo_process.setItemText(0, _translate("MainWindow", "Classification"))
        self.cbo_process.setItemText(1, _translate("MainWindow", "Clustering"))
        self.cbo_process.setItemText(2, _translate("MainWindow", "Regression"))
        self.frm_io.setAccessibleDescription(_translate("MainWindow", "<html><head/><body><p>Entrées/Sorties</p></body></html>"))
        self.__lbl_samples.setText(_translate("MainWindow", "Echantillons"))
        self.le_io_samples.setStatusTip(_translate("MainWindow", "Choisissez le fichier contenant les échantillons, ou 1 des jeux fournis : iris, digits ou boston"))
        self.btn_io_samples.setText(_translate("MainWindow", "..."))
        self.__lbl_data.setText(_translate("MainWindow", "Données"))
        self.le_io_data.setStatusTip(_translate("MainWindow", "Chemin vers le fichier contenant les données."))
        self.btn_io_data.setText(_translate("MainWindow", "..."))
        self.__gb_io_attributes.setTitle(_translate("MainWindow", "Attributs"))
        self.__lbl_io_label_id.setText(_translate("MainWindow", "label_id"))
        self.le_io_label_id.setStatusTip(_translate("MainWindow", "Indiquez ici si un attribut contient les identifiants de classe"))
        self.__lbl_io_label.setText(_translate("MainWindow", "label"))
        self.le_io_label.setStatusTip(_translate("MainWindow", "Indiquez ici si un attribut contient les libellés des classes"))
        self.__lbl_io_features.setText(_translate("MainWindow", "features"))
        self.le_io_features.setStatusTip(_translate("MainWindow", "Liste des attributs à utiliser (toutes si laissé vide)"))
        self.__lbl_output.setText(_translate("MainWindow", "Sortie (dossier)"))
        self.le_io_output.setStatusTip(_translate("MainWindow", "Chemin vers le dossier qui contiendra les résultats"))
        self.btn_io_output.setText(_translate("MainWindow", "..."))
        self.tbx_main.setItemText(self.tbx_main.indexOf(self.frm_io), _translate("MainWindow", "1 - Entrée(s)/Sortie"))
        self.chk_pre_scale.setStatusTip(_translate("MainWindow", "Faut-il centrer et réduire les données (oui par défaut) ?"))
        self.chk_pre_scale.setText(_translate("MainWindow", "Centrer/Réduire"))
        self.chk_pre_balance.setStatusTip(_translate("MainWindow", "Faut-il rééquilibrer les échantillons, c\'est à dire retirer des échantillons des classes qui en contiennent le plus ?"))
        self.chk_pre_balance.setText(_translate("MainWindow", "Equilibrage des échantillons"))
        self.chk_pre_separability.setStatusTip(_translate("MainWindow", "Faut-il tester la séparabilité des échantillons ?"))
        self.chk_pre_separability.setText(_translate("MainWindow", "Séparabilité"))
        self.gb_pre_reducion.setTitle(_translate("MainWindow", "Réduction"))
        self.__lbl_pre_reduce.setText(_translate("MainWindow", "Méthode"))
        self.cbo_pre_reduce.setStatusTip(_translate("MainWindow", "Faut-il réduire le jeu de données avant d\'appliquer les traitements ?"))
        self.__lbl_pre_ncomp.setText(_translate("MainWindow", "Nombre de dimensions"))
        self.sb_pre_ncomp.setStatusTip(_translate("MainWindow", "Nombre de dimensions souhaitées"))
        self.tbx_main.setItemText(self.tbx_main.indexOf(self.frm_preprocess), _translate("MainWindow", "2 - Prétraitements"))
        self.__lbl_pro_algorithm.setText(_translate("MainWindow", "Algorithmes"))
        self.lst_pro_algorithm.setStatusTip(_translate("MainWindow", "Choisissez parmi la liste le(s) algorithme(s) que vous souhaitez appliquer"))
        self.__lbl_pro_kfold.setText(_translate("MainWindow", "Validation croisée (kfold)"))
        self.sbo_pro_kfold.setStatusTip(_translate("MainWindow", "Nombre de lots à utiliser dans la validation croisée (3 par défaut)"))
        self.chk_pro_optimize.setStatusTip(_translate("MainWindow", "Faut-il rechercher les paramètres qui améliorent la précision des prédictions (non par défaut). Peut demander du temps."))
        self.chk_pro_optimize.setText(_translate("MainWindow", "Optimisation"))
        self.chk_pro_predict.setStatusTip(_translate("MainWindow", "Faut-il prédire des résultats ou simplement obtenir des résultats statistiques sur les échantillons (non par défaut)"))
        self.chk_pro_predict.setText(_translate("MainWindow", "Prédiction des résultats"))
        self.__lbl_pro_distance.setText(_translate("MainWindow", "Distance"))
        self.cbo_pro_distance.setStatusTip(_translate("MainWindow", "Quelle distance faut-il considérer (euclidienne par défaut)"))
        self.cbo_pro_distance.setItemText(0, _translate("MainWindow", "euclidean"))
        self.cbo_pro_distance.setItemText(1, _translate("MainWindow", "mahalanobis"))
        #self.btn_cancel.setText(_translate("MainWindow", "Annuler"))
        self.btn_run.setText(_translate("MainWindow", " Exécuter "))
        self.tbx_main.setItemText(self.tbx_main.indexOf(self.frm_process), _translate("MainWindow", "3 - Traitements"))
        self.btn_run.setStatusTip(_translate("MainWindow", "Lancer les traitements à réaliser"))
        self.menuFichier.setTitle(_translate("MainWindow", "Fichier"))
        self.menuAide.setTitle(_translate("MainWindow", "Aide"))
        self.dock_doc.setWindowTitle(_translate("MainWindow", "Didacticiel"))
        self.action_quit.setText(_translate("MainWindow", "Quitter"))
        self.action_quit.setStatusTip(_translate("MainWindow", "Quitter Mapping Learning"))
        self.action_quit.setShortcut(_translate("MainWindow", "Ctrl+Q"))
        self.action_open.setText(_translate("MainWindow", "Ouvrir"))
        self.action_open.setToolTip(_translate("MainWindow", "Ouvrir un fichier de configuration existant (*.cfg)"))
        self.action_open.setStatusTip(_translate("MainWindow", "Charger la configuration à partir d\'un fichier existant (*.cfg)"))
        self.action_open.setShortcut(_translate("MainWindow", "Ctrl+O"))
        self.action_new.setText(_translate("MainWindow", "Nouveau"))
        self.action_new.setToolTip(_translate("MainWindow", "Nouvelle configuration"))
        self.action_new.setStatusTip(_translate("MainWindow", "Créer une nouvelle configuration"))
        self.action_new.setShortcut(_translate("MainWindow", "Ctrl+N"))
        self.action_save.setText(_translate("MainWindow", "Enregistrer"))
        self.action_save.setStatusTip(_translate("MainWindow", "Enregistrer la configuration actuelle"))
        self.action_save.setShortcut(_translate("MainWindow", "Ctrl+S"))
        self.action_saveas.setText(_translate("MainWindow", "Enregistrer sous"))
        self.action_saveas.setStatusTip(_translate("MainWindow", "Enregistrer la configuration actuelle dans un nouveau fichier (*.cfg)"))
        self.action_saveas.setShortcut(_translate("MainWindow", "Ctrl+Shift+S"))
        self.action_doc.setText(_translate("MainWindow", "Documentation en ligne"))
        self.action_doc.setShortcut(_translate("MainWindow", "F1"))
        self.actionA_propos.setText(_translate("MainWindow", "A propos"))
